==> kgpr_core-0.7.3.tar.gz: kgpr_core-0.7.3/kgpr_core/google/gke/kresource.py <==
from typing import Optional, Any

from kubragen.kresource import KRPersistentVolumeProfile, KResourceDatabase, KRPersistentVolumeProfile_CSI
from kubragen.merger import Merger
from kubragen.object import ObjectItem
from kubragen.provider import Provider


class KRPersistentVolumeProfile_GCEPersistentDisk(KRPersistentVolumeProfile):
    """
    A PersisteVolume builder for Google Compute Engine Persistent Disk using the in-source Kubernetes driver.

    .. seealso:: `gcePersistentDisk <https://kubernetes.io/docs/concepts/storage/volumes/#gcepersistentdisk>`_.
    """
    def build(self, provider: Provider, resources: KResourceDatabase, name: str,
              config: Optional[Any], merge_config: Optional[Any]) -> ObjectItem:
        pvdata = {
            'apiVersion': 'v1',
            'kind': 'PersistentVolume',
            'metadata': {
                'name': name,
            },
            'spec': {
                'gcePersistentDisk': {},
            },
        }
        if config is not None:
            if 'name' in config:
                pvdata['metadata']['name'] = config['name']
            if 'csi' in config:
                if 'volumeHandle' in config['csi']:
                    pvdata['spec']['gcePersistentDisk']['pdName'] = config['csi']['volumeHandle']
                if 'fsType' in config['csi']:
                    pvdata['spec']['gcePersistentDisk']['fsType'] = config['csi']['fsType']
                if 'readOnly' in config['csi']:
                    pvdata['spec']['gcePersistentDisk']['readOnly'] = config['csi']['readOnly']

        return Merger.merge(pvdata, merge_config if merge_config is not None else {})


class KRPersistentVolumeProfile_CSI_GCEPD(KRPersistentVolumeProfile_CSI):
    """
    A PersisteVolume builder for Google Compute Engine Persistent Disk using the CSI driver.

    .. seealso:: `Using the Compute Engine persistent disk CSI Driver <https://cloud.google.com/kubernetes-engine/docs/how-to/persistent-volumes/gce-pd-csi-driver>`_.
    """
    def build(self, provider: Provider, resources: KResourceDatabase, name: str,
              config: Optional[Any], merge_config: Optional[Any]) -> ObjectItem:
        ret = super().build(provider, resources, name, config, merge_config)
        ret['spec']['csi']['driver'] = 'pd.csi.storage.gke.io'
        if config is not None:
            if 'nodriver' in config and config['nodriver'] is True:
                del ret['spec']['csi']['driver']
        return ret

==> kgpr_core-0.8.0.tar.gz: kgpr_core-0.8.0/kgpr_core/google/gke/kresource.py <==
from typing import Optional, Any

from kubragen.kresource import KRPersistentVolumeProfile, KResourceDatabase, KRPersistentVolumeProfile_CSI
from kubragen.merger import Merger
from kubragen.object import ObjectItem
from kubragen.provider import Provider


class KRPersistentVolumeProfile_GCEPersistentDisk(KRPersistentVolumeProfile):
    """
    A PersisteVolume builder for Google Compute Engine Persistent Disk using the in-source Kubernetes driver.

    .. seealso:: `gcePersistentDisk <https://kubernetes.io/docs/concepts/storage/volumes/#gcepersistentdisk>`_.
    """
    def build(self, provider: Provider, resources: KResourceDatabase, name: str,
              config: Optional[Any], merge_config: Optional[Any]) -> ObjectItem:
        pvdata = {
            'apiVersion': 'v1',
            'kind': 'PersistentVolume',
            'metadata': {
                'name': name,
            },
            'spec': {
                'gcePersistentDisk': {},
            },
        }
        if self.storageclass is not None:
            pvdata['spec']['storageClassName'] = self.storageclass
        is_static = False
        if config is not None:
            if 'name' in config:
                pvdata['metadata']['name'] = config['name']
            if 'csi' in config:
                if 'volumeHandle' in config['csi']:
                    is_static = True
                    pvdata['spec']['gcePersistentDisk']['pdName'] = config['csi']['volumeHandle']
                if 'fsType' in config['csi']:
                    pvdata['spec']['gcePersistentDisk']['fsType'] = config['csi']['fsType']
                if 'readOnly' in config['csi']:
                    pvdata['spec']['gcePersistentDisk']['readOnly'] = config['csi']['readOnly']

        ret = Merger.merge(pvdata, merge_config if merge_config is not None else {})

        if is_static:
            # Static storage must set class name as ''
            ret['spec']['storageClassName'] = ''

        return ret


class KRPersistentVolumeProfile_CSI_GCEPD(KRPersistentVolumeProfile_CSI):
    """
    A PersisteVolume builder for Google Compute Engine Persistent Disk using the CSI driver.

    .. seealso:: `Using the Compute Engine persistent disk CSI Driver <https://cloud.google.com/kubernetes-engine/docs/how-to/persistent-volumes/gce-pd-csi-driver>`_.
    """
    def build(self, provider: Provider, resources: KResourceDatabase, name: str,
              config: Optional[Any], merge_config: Optional[Any]) -> ObjectItem:
        ret = super().build(provider, resources, name, config, merge_config)
        ret['spec']['csi']['driver'] = 'pd.csi.storage.gke.io'
        if config is not None:
            if 'nodriver' in config and config['nodriver'] is True:
                del ret['spec']['csi']['driver']
        return ret
